@@ -17,7 +17,7 @@ import matplotlib.gridspec as gridspec
 from matplotlib.colorbar import Colorbar
 import matplotlib.ticker as ticker
 
-import ca_utils
+from localnmf import ca_utils
 
 
 '''
